# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/auto_tuning_raw_feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/auto_tuning_raw_feature.proto',
  package='apollo.planning.autotuning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/planning/proto/auto_tuning_raw_feature.proto\x12\x1a\x61pollo.planning.autotuning\x1a$modules/common/proto/pnc_point.proto\"\x7f\n\x13PathPointRawFeature\x12\x31\n\x0f\x63\x61rtesian_coord\x18\x01 \x01(\x0b\x32\x18.apollo.common.PathPoint\x12\x35\n\x0c\x66renet_coord\x18\x02 \x01(\x0b\x32\x1f.apollo.common.FrenetFramePoint\"\x89\x08\n\x14SpeedPointRawFeature\x12\t\n\x01s\x18\x01 \x01(\x01\x12\t\n\x01t\x18\x02 \x01(\x01\x12\t\n\x01v\x18\x03 \x01(\x01\x12\t\n\x01\x61\x18\x04 \x01(\x01\x12\t\n\x01j\x18\x05 \x01(\x01\x12\x13\n\x0bspeed_limit\x18\x06 \x01(\x01\x12V\n\x06\x66ollow\x18\n \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12X\n\x08overtake\x18\x0b \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12`\n\x10virtual_decision\x18\r \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12T\n\x04stop\x18\x0e \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12Y\n\tcollision\x18\x0f \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12U\n\x05nudge\x18\x0c \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12^\n\x0esidepass_front\x18\x10 \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12]\n\rsidepass_rear\x18\x11 \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x12Z\n\nkeep_clear\x18\x12 \x03(\x0b\x32\x46.apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature\x1an\n\x15ObjectDecisionFeature\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nrelative_s\x18\x02 \x01(\x01\x12\x12\n\nrelative_l\x18\x03 \x01(\x01\x12\x12\n\nrelative_v\x18\x04 \x01(\x01\x12\r\n\x05speed\x18\x05 \x01(\x01\"\xdf\x04\n\x11ObstacleSTRawData\x12V\n\x10obstacle_st_data\x18\x01 \x03(\x0b\x32<.apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData\x12W\n\x11obstacle_st_nudge\x18\x02 \x03(\x0b\x32<.apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData\x12Z\n\x14obstacle_st_sidepass\x18\x03 \x03(\x0b\x32<.apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData\x1aI\n\x0bSTPointPair\x12\x0f\n\x07s_lower\x18\x01 \x01(\x01\x12\x0f\n\x07s_upper\x18\x02 \x01(\x01\x12\t\n\x01t\x18\x03 \x01(\x01\x12\r\n\x01l\x18\x04 \x01(\x01:\x02\x31\x30\x1a\xf1\x01\n\x0eObstacleSTData\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05speed\x18\x02 \x01(\x01\x12\x12\n\nis_virtual\x18\x03 \x01(\x08\x12\x13\n\x0bprobability\x18\x04 \x01(\x01\x12J\n\x07polygon\x18\x08 \x03(\x0b\x32\x39.apollo.planning.autotuning.ObstacleSTRawData.STPointPair\x12O\n\x0c\x64istribution\x18\t \x03(\x0b\x32\x39.apollo.planning.autotuning.ObstacleSTRawData.STPointPair\"\xab\x01\n\x19TrajectoryPointRawFeature\x12\x45\n\x0cpath_feature\x18\x01 \x01(\x0b\x32/.apollo.planning.autotuning.PathPointRawFeature\x12G\n\rspeed_feature\x18\x02 \x01(\x0b\x32\x30.apollo.planning.autotuning.SpeedPointRawFeature\"\xa8\x01\n\x14TrajectoryRawFeature\x12L\n\rpoint_feature\x18\x01 \x03(\x0b\x32\x35.apollo.planning.autotuning.TrajectoryPointRawFeature\x12\x42\n\x0bst_raw_data\x18\x02 \x01(\x0b\x32-.apollo.planning.autotuning.ObstacleSTRawData'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,])




_PATHPOINTRAWFEATURE = _descriptor.Descriptor(
  name='PathPointRawFeature',
  full_name='apollo.planning.autotuning.PathPointRawFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cartesian_coord', full_name='apollo.planning.autotuning.PathPointRawFeature.cartesian_coord', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frenet_coord', full_name='apollo.planning.autotuning.PathPointRawFeature.frenet_coord', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=249,
)


_SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE = _descriptor.Descriptor(
  name='ObjectDecisionFeature',
  full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_s', full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature.relative_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_l', full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature.relative_l', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_v', full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature.relative_v', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature.speed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1285,
)

_SPEEDPOINTRAWFEATURE = _descriptor.Descriptor(
  name='SpeedPointRawFeature',
  full_name='apollo.planning.autotuning.SpeedPointRawFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning.autotuning.SpeedPointRawFeature.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning.autotuning.SpeedPointRawFeature.t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.planning.autotuning.SpeedPointRawFeature.v', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.planning.autotuning.SpeedPointRawFeature.a', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='j', full_name='apollo.planning.autotuning.SpeedPointRawFeature.j', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.planning.autotuning.SpeedPointRawFeature.speed_limit', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='follow', full_name='apollo.planning.autotuning.SpeedPointRawFeature.follow', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overtake', full_name='apollo.planning.autotuning.SpeedPointRawFeature.overtake', index=7,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_decision', full_name='apollo.planning.autotuning.SpeedPointRawFeature.virtual_decision', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop', full_name='apollo.planning.autotuning.SpeedPointRawFeature.stop', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collision', full_name='apollo.planning.autotuning.SpeedPointRawFeature.collision', index=10,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nudge', full_name='apollo.planning.autotuning.SpeedPointRawFeature.nudge', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sidepass_front', full_name='apollo.planning.autotuning.SpeedPointRawFeature.sidepass_front', index=12,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sidepass_rear', full_name='apollo.planning.autotuning.SpeedPointRawFeature.sidepass_rear', index=13,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keep_clear', full_name='apollo.planning.autotuning.SpeedPointRawFeature.keep_clear', index=14,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=1285,
)


_OBSTACLESTRAWDATA_STPOINTPAIR = _descriptor.Descriptor(
  name='STPointPair',
  full_name='apollo.planning.autotuning.ObstacleSTRawData.STPointPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s_lower', full_name='apollo.planning.autotuning.ObstacleSTRawData.STPointPair.s_lower', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s_upper', full_name='apollo.planning.autotuning.ObstacleSTRawData.STPointPair.s_upper', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.planning.autotuning.ObstacleSTRawData.STPointPair.t', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.planning.autotuning.ObstacleSTRawData.STPointPair.l', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1578,
  serialized_end=1651,
)

_OBSTACLESTRAWDATA_OBSTACLESTDATA = _descriptor.Descriptor(
  name='ObstacleSTData',
  full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.speed', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.is_virtual', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.probability', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.polygon', index=4,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution', full_name='apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData.distribution', index=5,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1895,
)

_OBSTACLESTRAWDATA = _descriptor.Descriptor(
  name='ObstacleSTRawData',
  full_name='apollo.planning.autotuning.ObstacleSTRawData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_st_data', full_name='apollo.planning.autotuning.ObstacleSTRawData.obstacle_st_data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_st_nudge', full_name='apollo.planning.autotuning.ObstacleSTRawData.obstacle_st_nudge', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_st_sidepass', full_name='apollo.planning.autotuning.ObstacleSTRawData.obstacle_st_sidepass', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSTACLESTRAWDATA_STPOINTPAIR, _OBSTACLESTRAWDATA_OBSTACLESTDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1895,
)


_TRAJECTORYPOINTRAWFEATURE = _descriptor.Descriptor(
  name='TrajectoryPointRawFeature',
  full_name='apollo.planning.autotuning.TrajectoryPointRawFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_feature', full_name='apollo.planning.autotuning.TrajectoryPointRawFeature.path_feature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_feature', full_name='apollo.planning.autotuning.TrajectoryPointRawFeature.speed_feature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1898,
  serialized_end=2069,
)


_TRAJECTORYRAWFEATURE = _descriptor.Descriptor(
  name='TrajectoryRawFeature',
  full_name='apollo.planning.autotuning.TrajectoryRawFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point_feature', full_name='apollo.planning.autotuning.TrajectoryRawFeature.point_feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='st_raw_data', full_name='apollo.planning.autotuning.TrajectoryRawFeature.st_raw_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2072,
  serialized_end=2240,
)

_PATHPOINTRAWFEATURE.fields_by_name['cartesian_coord'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATHPOINT
_PATHPOINTRAWFEATURE.fields_by_name['frenet_coord'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._FRENETFRAMEPOINT
_SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE.containing_type = _SPEEDPOINTRAWFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['follow'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['overtake'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['virtual_decision'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['stop'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['collision'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['nudge'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['sidepass_front'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['sidepass_rear'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_SPEEDPOINTRAWFEATURE.fields_by_name['keep_clear'].message_type = _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE
_OBSTACLESTRAWDATA_STPOINTPAIR.containing_type = _OBSTACLESTRAWDATA
_OBSTACLESTRAWDATA_OBSTACLESTDATA.fields_by_name['polygon'].message_type = _OBSTACLESTRAWDATA_STPOINTPAIR
_OBSTACLESTRAWDATA_OBSTACLESTDATA.fields_by_name['distribution'].message_type = _OBSTACLESTRAWDATA_STPOINTPAIR
_OBSTACLESTRAWDATA_OBSTACLESTDATA.containing_type = _OBSTACLESTRAWDATA
_OBSTACLESTRAWDATA.fields_by_name['obstacle_st_data'].message_type = _OBSTACLESTRAWDATA_OBSTACLESTDATA
_OBSTACLESTRAWDATA.fields_by_name['obstacle_st_nudge'].message_type = _OBSTACLESTRAWDATA_OBSTACLESTDATA
_OBSTACLESTRAWDATA.fields_by_name['obstacle_st_sidepass'].message_type = _OBSTACLESTRAWDATA_OBSTACLESTDATA
_TRAJECTORYPOINTRAWFEATURE.fields_by_name['path_feature'].message_type = _PATHPOINTRAWFEATURE
_TRAJECTORYPOINTRAWFEATURE.fields_by_name['speed_feature'].message_type = _SPEEDPOINTRAWFEATURE
_TRAJECTORYRAWFEATURE.fields_by_name['point_feature'].message_type = _TRAJECTORYPOINTRAWFEATURE
_TRAJECTORYRAWFEATURE.fields_by_name['st_raw_data'].message_type = _OBSTACLESTRAWDATA
DESCRIPTOR.message_types_by_name['PathPointRawFeature'] = _PATHPOINTRAWFEATURE
DESCRIPTOR.message_types_by_name['SpeedPointRawFeature'] = _SPEEDPOINTRAWFEATURE
DESCRIPTOR.message_types_by_name['ObstacleSTRawData'] = _OBSTACLESTRAWDATA
DESCRIPTOR.message_types_by_name['TrajectoryPointRawFeature'] = _TRAJECTORYPOINTRAWFEATURE
DESCRIPTOR.message_types_by_name['TrajectoryRawFeature'] = _TRAJECTORYRAWFEATURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PathPointRawFeature = _reflection.GeneratedProtocolMessageType('PathPointRawFeature', (_message.Message,), {
  'DESCRIPTOR' : _PATHPOINTRAWFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.PathPointRawFeature)
  })
_sym_db.RegisterMessage(PathPointRawFeature)

SpeedPointRawFeature = _reflection.GeneratedProtocolMessageType('SpeedPointRawFeature', (_message.Message,), {

  'ObjectDecisionFeature' : _reflection.GeneratedProtocolMessageType('ObjectDecisionFeature', (_message.Message,), {
    'DESCRIPTOR' : _SPEEDPOINTRAWFEATURE_OBJECTDECISIONFEATURE,
    '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.SpeedPointRawFeature.ObjectDecisionFeature)
    })
  ,
  'DESCRIPTOR' : _SPEEDPOINTRAWFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.SpeedPointRawFeature)
  })
_sym_db.RegisterMessage(SpeedPointRawFeature)
_sym_db.RegisterMessage(SpeedPointRawFeature.ObjectDecisionFeature)

ObstacleSTRawData = _reflection.GeneratedProtocolMessageType('ObstacleSTRawData', (_message.Message,), {

  'STPointPair' : _reflection.GeneratedProtocolMessageType('STPointPair', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESTRAWDATA_STPOINTPAIR,
    '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.ObstacleSTRawData.STPointPair)
    })
  ,

  'ObstacleSTData' : _reflection.GeneratedProtocolMessageType('ObstacleSTData', (_message.Message,), {
    'DESCRIPTOR' : _OBSTACLESTRAWDATA_OBSTACLESTDATA,
    '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.ObstacleSTRawData.ObstacleSTData)
    })
  ,
  'DESCRIPTOR' : _OBSTACLESTRAWDATA,
  '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.ObstacleSTRawData)
  })
_sym_db.RegisterMessage(ObstacleSTRawData)
_sym_db.RegisterMessage(ObstacleSTRawData.STPointPair)
_sym_db.RegisterMessage(ObstacleSTRawData.ObstacleSTData)

TrajectoryPointRawFeature = _reflection.GeneratedProtocolMessageType('TrajectoryPointRawFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYPOINTRAWFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.TrajectoryPointRawFeature)
  })
_sym_db.RegisterMessage(TrajectoryPointRawFeature)

TrajectoryRawFeature = _reflection.GeneratedProtocolMessageType('TrajectoryRawFeature', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYRAWFEATURE,
  '__module__' : 'modules.planning.proto.auto_tuning_raw_feature_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.autotuning.TrajectoryRawFeature)
  })
_sym_db.RegisterMessage(TrajectoryRawFeature)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/fusion_camera_detection_component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/fusion_camera_detection_component.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHmodules/perception/onboard/proto/fusion_camera_detection_component.proto\x12\x19\x61pollo.perception.onboard\"\xb5\x0b\n\x15\x46usionCameraDetection\x12*\n\x0c\x63\x61mera_names\x18\x01 \x01(\t:\x14\x66ront_6mm,front_12mm\x12k\n\x1ainput_camera_channel_names\x18\x02 \x01(\t:G/sensor/camera/traffic/image_short,/sensor/camera/obstacle/image_narrow\x12\x1b\n\x10timestamp_offset\x18\x03 \x01(\x01:\x01\x30\x12\x43\n#camera_obstacle_perception_conf_dir\x18\x04 \x01(\t:\x16\x63onf/perception/camera\x12\x39\n$camera_obstacle_perception_conf_file\x18\x05 \x01(\t:\x0bobstacle.pt\x12\x1a\n\x0e\x66rame_capacity\x18\x06 \x01(\x05:\x02\x32\x30\x12\x1c\n\x11image_channel_num\x18\x07 \x01(\x05:\x01\x33\x12\"\n\x13\x65nable_undistortion\x18\x08 \x01(\x08:\x05\x66\x61lse\x12#\n\x14\x65nable_visualization\x18\t \x01(\x08:\x05\x66\x61lse\x12<\n\x1doutput_obstacles_channel_name\x18\n \x01(\t:\x15/perception/obstacles\x12T\n*camera_perception_viz_message_channel_name\x18\x0b \x01(\t: /perception/inner/camera_viz_msg\x12@\n\x15prefused_channel_name\x18\x0c \x01(\t:!/perception/inner/PrefusedObjects\x12\x1f\n\x14\x64\x65\x66\x61ult_camera_pitch\x18\r \x01(\x01:\x01\x30\x12\"\n\x15\x64\x65\x66\x61ult_camera_height\x18\x0e \x01(\x01:\x03\x31.5\x12\x37\n$lane_calibration_working_sensor_name\x18\x0f \x01(\t:\tfront_6mm\x12-\n\x11\x63\x61librator_method\x18\x10 \x01(\t:\x12LaneLineCalibrator\x12\x34\n\x12\x63\x61lib_service_name\x18\x11 \x01(\t:\x18OnlineCalibrationService\x12\x1f\n\x11run_calib_service\x18\x12 \x01(\x08:\x04true\x12&\n\x17output_camera_debug_msg\x18\x13 \x01(\x08:\x05\x66\x61lse\x12;\n\x19\x63\x61mera_debug_channel_name\x18\x14 \x01(\t:\x18/perception/camera_debug\x12\x14\n\x07ts_diff\x18\x15 \x01(\x01:\x03\x30.1\x12%\n\x16output_final_obstacles\x18\x16 \x01(\x08:\x05\x66\x61lse\x12\x31\n\x13visual_debug_folder\x18\x17 \x01(\t:\x14/apollo/debug_output\x12 \n\rvisual_camera\x18\x18 \x01(\t:\tfront_6mm\x12\x1f\n\x10write_visual_img\x18\x19 \x01(\x08:\x05\x66\x61lse\x12\'\n\x1cmin_laneline_length_for_cipv\x18\x1a \x01(\x01:\x01\x32\x12(\n\x1b\x61verage_lane_width_in_meter\x18\x1b \x01(\x01:\x03\x33.7\x12\'\n\x1amax_vehicle_width_in_meter\x18\x1c \x01(\x01:\x03\x32.5\x12 \n\x12\x61verage_frame_rate\x18\x1d \x01(\x01:\x04\x30.05\x12\x1f\n\x10image_based_cipv\x18\x1e \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0b\x64\x65\x62ug_level\x18\x1f \x01(\x05:\x01\x30\x12\x1a\n\x0b\x65nable_cipv\x18  \x01(\x08:\x05\x66\x61lse'
)




_FUSIONCAMERADETECTION = _descriptor.Descriptor(
  name='FusionCameraDetection',
  full_name='apollo.perception.onboard.FusionCameraDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.FusionCameraDetection.camera_names', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm,front_12mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_camera_channel_names', full_name='apollo.perception.onboard.FusionCameraDetection.input_camera_channel_names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/sensor/camera/traffic/image_short,/sensor/camera/obstacle/image_narrow".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_offset', full_name='apollo.perception.onboard.FusionCameraDetection.timestamp_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_obstacle_perception_conf_dir', full_name='apollo.perception.onboard.FusionCameraDetection.camera_obstacle_perception_conf_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conf/perception/camera".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_obstacle_perception_conf_file', full_name='apollo.perception.onboard.FusionCameraDetection.camera_obstacle_perception_conf_file', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"obstacle.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_capacity', full_name='apollo.perception.onboard.FusionCameraDetection.frame_capacity', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_channel_num', full_name='apollo.perception.onboard.FusionCameraDetection.image_channel_num', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_undistortion', full_name='apollo.perception.onboard.FusionCameraDetection.enable_undistortion', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_visualization', full_name='apollo.perception.onboard.FusionCameraDetection.enable_visualization', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_obstacles_channel_name', full_name='apollo.perception.onboard.FusionCameraDetection.output_obstacles_channel_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/obstacles".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_perception_viz_message_channel_name', full_name='apollo.perception.onboard.FusionCameraDetection.camera_perception_viz_message_channel_name', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/inner/camera_viz_msg".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefused_channel_name', full_name='apollo.perception.onboard.FusionCameraDetection.prefused_channel_name', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/inner/PrefusedObjects".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_pitch', full_name='apollo.perception.onboard.FusionCameraDetection.default_camera_pitch', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_height', full_name='apollo.perception.onboard.FusionCameraDetection.default_camera_height', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_calibration_working_sensor_name', full_name='apollo.perception.onboard.FusionCameraDetection.lane_calibration_working_sensor_name', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibrator_method', full_name='apollo.perception.onboard.FusionCameraDetection.calibrator_method', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"LaneLineCalibrator".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calib_service_name', full_name='apollo.perception.onboard.FusionCameraDetection.calib_service_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"OnlineCalibrationService".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_calib_service', full_name='apollo.perception.onboard.FusionCameraDetection.run_calib_service', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_camera_debug_msg', full_name='apollo.perception.onboard.FusionCameraDetection.output_camera_debug_msg', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_debug_channel_name', full_name='apollo.perception.onboard.FusionCameraDetection.camera_debug_channel_name', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/camera_debug".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_diff', full_name='apollo.perception.onboard.FusionCameraDetection.ts_diff', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_final_obstacles', full_name='apollo.perception.onboard.FusionCameraDetection.output_final_obstacles', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_debug_folder', full_name='apollo.perception.onboard.FusionCameraDetection.visual_debug_folder', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/debug_output".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_camera', full_name='apollo.perception.onboard.FusionCameraDetection.visual_camera', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_visual_img', full_name='apollo.perception.onboard.FusionCameraDetection.write_visual_img', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_laneline_length_for_cipv', full_name='apollo.perception.onboard.FusionCameraDetection.min_laneline_length_for_cipv', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_lane_width_in_meter', full_name='apollo.perception.onboard.FusionCameraDetection.average_lane_width_in_meter', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3.7),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_vehicle_width_in_meter', full_name='apollo.perception.onboard.FusionCameraDetection.max_vehicle_width_in_meter', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_frame_rate', full_name='apollo.perception.onboard.FusionCameraDetection.average_frame_rate', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.05),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_based_cipv', full_name='apollo.perception.onboard.FusionCameraDetection.image_based_cipv', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_level', full_name='apollo.perception.onboard.FusionCameraDetection.debug_level', index=30,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_cipv', full_name='apollo.perception.onboard.FusionCameraDetection.enable_cipv', index=31,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=1565,
)

DESCRIPTOR.message_types_by_name['FusionCameraDetection'] = _FUSIONCAMERADETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FusionCameraDetection = _reflection.GeneratedProtocolMessageType('FusionCameraDetection', (_message.Message,), {
  'DESCRIPTOR' : _FUSIONCAMERADETECTION,
  '__module__' : 'modules.perception.onboard.proto.fusion_camera_detection_component_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.FusionCameraDetection)
  })
_sym_db.RegisterMessage(FusionCameraDetection)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/lane_perception_component.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/lane_perception_component.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@modules/perception/onboard/proto/lane_perception_component.proto\x12\x19\x61pollo.perception.onboard\"\x87\x07\n\rLaneDetection\x12*\n\x0c\x63\x61mera_names\x18\x01 \x01(\t:\x14\x66ront_6mm,front_12mm\x12p\n\x1ainput_camera_channel_names\x18\x02 \x01(\t:L/apollo/sensor/camera/front_6mm/image,/apollo/sensor/camera/front_12mm/image\x12\x1b\n\x10timestamp_offset\x18\x03 \x01(\x01:\x01\x30\x12?\n\x1f\x63\x61mera_lane_perception_conf_dir\x18\x04 \x01(\t:\x16\x63onf/perception/camera\x12\x31\n camera_lane_perception_conf_file\x18\x05 \x01(\t:\x07lane.pt\x12\x1a\n\x0e\x66rame_capacity\x18\x06 \x01(\x05:\x02\x32\x30\x12\x1c\n\x11image_channel_num\x18\x07 \x01(\x05:\x01\x33\x12\"\n\x13\x65nable_undistortion\x18\x08 \x01(\x08:\x05\x66\x61lse\x12#\n\x14\x65nable_visualization\x18\t \x01(\x08:\x05\x66\x61lse\x12\x34\n\x19output_lanes_channel_name\x18\n \x01(\t:\x11/perception/lanes\x12\x1f\n\x14\x64\x65\x66\x61ult_camera_pitch\x18\x0b \x01(\x01:\x01\x30\x12\"\n\x15\x64\x65\x66\x61ult_camera_height\x18\x0c \x01(\x01:\x03\x31.5\x12\x37\n$lane_calibration_working_sensor_name\x18\r \x01(\t:\tfront_6mm\x12-\n\x11\x63\x61librator_method\x18\x0e \x01(\t:\x12LaneLineCalibrator\x12\x34\n\x12\x63\x61lib_service_name\x18\x0f \x01(\t:\x18OnlineCalibrationService\x12\x1f\n\x11run_calib_service\x18\x10 \x01(\x08:\x04true\x12\x14\n\x07ts_diff\x18\x11 \x01(\x01:\x03\x30.1\x12\x31\n\x13visual_debug_folder\x18\x12 \x01(\t:\x14/apollo/debug_output\x12 \n\rvisual_camera\x18\x13 \x01(\t:\tfront_6mm\x12\x1f\n\x10write_visual_img\x18\x14 \x01(\x08:\x05\x66\x61lse'
)




_LANEDETECTION = _descriptor.Descriptor(
  name='LaneDetection',
  full_name='apollo.perception.onboard.LaneDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.LaneDetection.camera_names', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm,front_12mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_camera_channel_names', full_name='apollo.perception.onboard.LaneDetection.input_camera_channel_names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/sensor/camera/front_6mm/image,/apollo/sensor/camera/front_12mm/image".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_offset', full_name='apollo.perception.onboard.LaneDetection.timestamp_offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_lane_perception_conf_dir', full_name='apollo.perception.onboard.LaneDetection.camera_lane_perception_conf_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"conf/perception/camera".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_lane_perception_conf_file', full_name='apollo.perception.onboard.LaneDetection.camera_lane_perception_conf_file', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"lane.pt".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_capacity', full_name='apollo.perception.onboard.LaneDetection.frame_capacity', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_channel_num', full_name='apollo.perception.onboard.LaneDetection.image_channel_num', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_undistortion', full_name='apollo.perception.onboard.LaneDetection.enable_undistortion', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_visualization', full_name='apollo.perception.onboard.LaneDetection.enable_visualization', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_lanes_channel_name', full_name='apollo.perception.onboard.LaneDetection.output_lanes_channel_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/perception/lanes".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_pitch', full_name='apollo.perception.onboard.LaneDetection.default_camera_pitch', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_camera_height', full_name='apollo.perception.onboard.LaneDetection.default_camera_height', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_calibration_working_sensor_name', full_name='apollo.perception.onboard.LaneDetection.lane_calibration_working_sensor_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibrator_method', full_name='apollo.perception.onboard.LaneDetection.calibrator_method', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"LaneLineCalibrator".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calib_service_name', full_name='apollo.perception.onboard.LaneDetection.calib_service_name', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"OnlineCalibrationService".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_calib_service', full_name='apollo.perception.onboard.LaneDetection.run_calib_service', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_diff', full_name='apollo.perception.onboard.LaneDetection.ts_diff', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_debug_folder', full_name='apollo.perception.onboard.LaneDetection.visual_debug_folder', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/debug_output".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visual_camera', full_name='apollo.perception.onboard.LaneDetection.visual_camera', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_visual_img', full_name='apollo.perception.onboard.LaneDetection.write_visual_img', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=999,
)

DESCRIPTOR.message_types_by_name['LaneDetection'] = _LANEDETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneDetection = _reflection.GeneratedProtocolMessageType('LaneDetection', (_message.Message,), {
  'DESCRIPTOR' : _LANEDETECTION,
  '__module__' : 'modules.perception.onboard.proto.lane_perception_component_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.LaneDetection)
  })
_sym_db.RegisterMessage(LaneDetection)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/onboard/proto/motion_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/onboard/proto/motion_service.proto',
  package='apollo.perception.onboard',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/perception/onboard/proto/motion_service.proto\x12\x19\x61pollo.perception.onboard\"\x85\x02\n\rMotionService\x12\x1f\n\x0c\x63\x61mera_names\x18\x01 \x01(\t:\tfront_6mm\x12I\n\x1ainput_camera_channel_names\x18\x02 \x01(\t:%/apollo/sensor/camera/front_6mm/image\x12\x42\n\x1finput_localization_channel_name\x18\x03 \x01(\t:\x19/apollo/localization/pose\x12\x44\n\x19output_topic_channel_name\x18\x04 \x01(\t:!/apollo/perception/motion_service'
)




_MOTIONSERVICE = _descriptor.Descriptor(
  name='MotionService',
  full_name='apollo.perception.onboard.MotionService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_names', full_name='apollo.perception.onboard.MotionService.camera_names', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"front_6mm".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_camera_channel_names', full_name='apollo.perception.onboard.MotionService.input_camera_channel_names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/sensor/camera/front_6mm/image".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_localization_channel_name', full_name='apollo.perception.onboard.MotionService.input_localization_channel_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/localization/pose".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_topic_channel_name', full_name='apollo.perception.onboard.MotionService.output_topic_channel_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"/apollo/perception/motion_service".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=346,
)

DESCRIPTOR.message_types_by_name['MotionService'] = _MOTIONSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionService = _reflection.GeneratedProtocolMessageType('MotionService', (_message.Message,), {
  'DESCRIPTOR' : _MOTIONSERVICE,
  '__module__' : 'modules.perception.onboard.proto.motion_service_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.onboard.MotionService)
  })
_sym_db.RegisterMessage(MotionService)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/ins.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/ins.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/drivers/gnss/proto/ins.proto\x12\x13\x61pollo.drivers.gnss\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"V\n\x07InsStat\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x12\n\nins_status\x18\x02 \x01(\r\x12\x10\n\x08pos_type\x18\x03 \x01(\r\"\xd6\x04\n\x03Ins\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x18\n\x10measurement_time\x18\x02 \x01(\x01\x12+\n\x04type\x18\x03 \x01(\x0e\x32\x1d.apollo.drivers.gnss.Ins.Type\x12)\n\x08position\x18\x04 \x01(\x0b\x32\x17.apollo.common.PointLLH\x12,\n\x0c\x65uler_angles\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D\x12/\n\x0flinear_velocity\x18\x06 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x30\n\x10\x61ngular_velocity\x18\x07 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x33\n\x13linear_acceleration\x18\x08 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x1f\n\x13position_covariance\x18\t \x03(\x02\x42\x02\x10\x01\x12#\n\x17\x65uler_angles_covariance\x18\n \x03(\x02\x42\x02\x10\x01\x12&\n\x1alinear_velocity_covariance\x18\x0b \x03(\x02\x42\x02\x10\x01\x12\'\n\x1b\x61ngular_velocity_covariance\x18\x0c \x03(\x02\x42\x02\x10\x01\x12*\n\x1elinear_acceleration_covariance\x18\r \x03(\x02\x42\x02\x10\x01\"-\n\x04Type\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nCONVERGING\x10\x01\x12\x08\n\x04GOOD\x10\x02'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_INS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.drivers.gnss.Ins.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONVERGING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=775,
  serialized_end=820,
)
_sym_db.RegisterEnumDescriptor(_INS_TYPE)


_INSSTAT = _descriptor.Descriptor(
  name='InsStat',
  full_name='apollo.drivers.gnss.InsStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.InsStat.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ins_status', full_name='apollo.drivers.gnss.InsStat.ins_status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_type', full_name='apollo.drivers.gnss.InsStat.pos_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=133,
  serialized_end=219,
)


_INS = _descriptor.Descriptor(
  name='Ins',
  full_name='apollo.drivers.gnss.Ins',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.Ins.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.gnss.Ins.measurement_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.drivers.gnss.Ins.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.drivers.gnss.Ins.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='euler_angles', full_name='apollo.drivers.gnss.Ins.euler_angles', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='apollo.drivers.gnss.Ins.linear_velocity', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='apollo.drivers.gnss.Ins.angular_velocity', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='apollo.drivers.gnss.Ins.linear_acceleration', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_covariance', full_name='apollo.drivers.gnss.Ins.position_covariance', index=8,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='euler_angles_covariance', full_name='apollo.drivers.gnss.Ins.euler_angles_covariance', index=9,
      number=10, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity_covariance', full_name='apollo.drivers.gnss.Ins.linear_velocity_covariance', index=10,
      number=11, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity_covariance', full_name='apollo.drivers.gnss.Ins.angular_velocity_covariance', index=11,
      number=12, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration_covariance', full_name='apollo.drivers.gnss.Ins.linear_acceleration_covariance', index=12,
      number=13, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=820,
)

_INSSTAT.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INS.fields_by_name['type'].enum_type = _INS_TYPE
_INS.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTLLH
_INS.fields_by_name['euler_angles'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INS.fields_by_name['linear_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INS.fields_by_name['angular_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INS.fields_by_name['linear_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INS_TYPE.containing_type = _INS
DESCRIPTOR.message_types_by_name['InsStat'] = _INSSTAT
DESCRIPTOR.message_types_by_name['Ins'] = _INS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InsStat = _reflection.GeneratedProtocolMessageType('InsStat', (_message.Message,), {
  'DESCRIPTOR' : _INSSTAT,
  '__module__' : 'modules.drivers.gnss.proto.ins_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.InsStat)
  })
_sym_db.RegisterMessage(InsStat)

Ins = _reflection.GeneratedProtocolMessageType('Ins', (_message.Message,), {
  'DESCRIPTOR' : _INS,
  '__module__' : 'modules.drivers.gnss.proto.ins_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.Ins)
  })
_sym_db.RegisterMessage(Ins)


_INS.fields_by_name['position_covariance']._options = None
_INS.fields_by_name['euler_angles_covariance']._options = None
_INS.fields_by_name['linear_velocity_covariance']._options = None
_INS.fields_by_name['angular_velocity_covariance']._options = None
_INS.fields_by_name['linear_acceleration_covariance']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/mpc_controller_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.control.proto import calibration_table_pb2 as modules_dot_control_dot_proto_dot_calibration__table__pb2
from modules.control.proto import gain_scheduler_conf_pb2 as modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/mpc_controller_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/control/proto/mpc_controller_conf.proto\x12\x0e\x61pollo.control\x1a-modules/control/proto/calibration_table.proto\x1a/modules/control/proto/gain_scheduler_conf.proto\"\xbb\x06\n\x11MPCControllerConf\x12\n\n\x02ts\x18\x01 \x01(\x01\x12\n\n\x02\x63\x66\x18\x02 \x01(\x01\x12\n\n\x02\x63r\x18\x03 \x01(\x01\x12\x0f\n\x07mass_fl\x18\x04 \x01(\x05\x12\x0f\n\x07mass_fr\x18\x05 \x01(\x05\x12\x0f\n\x07mass_rl\x18\x06 \x01(\x05\x12\x0f\n\x07mass_rr\x18\x07 \x01(\x05\x12\x0b\n\x03\x65ps\x18\x08 \x01(\x01\x12\x10\n\x08matrix_q\x18\t \x03(\x01\x12\x10\n\x08matrix_r\x18\n \x03(\x01\x12\x13\n\x0b\x63utoff_freq\x18\x0b \x01(\x05\x12\x1f\n\x17mean_filter_window_size\x18\x0c \x01(\x05\x12\x15\n\rmax_iteration\x18\r \x01(\x05\x12 \n\x18max_lateral_acceleration\x18\x0e \x01(\x01\x12\x1f\n\x17standstill_acceleration\x18\x0f \x01(\x01\x12\x1c\n\x14\x62rake_minimum_action\x18\x10 \x01(\x01\x12\x1f\n\x17throttle_minimum_action\x18\x11 \x01(\x01\x12=\n\x16lat_err_gain_scheduler\x18\x12 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x41\n\x1aheading_err_gain_scheduler\x18\x13 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x42\n\x1bsteer_weight_gain_scheduler\x18\x14 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12\x45\n\x1e\x66\x65\x65\x64\x66orwardterm_gain_scheduler\x18\x15 \x01(\x0b\x32\x1d.apollo.control.GainScheduler\x12S\n\x11\x63\x61libration_table\x18\x16 \x01(\x0b\x32\x38.apollo.control.calibrationtable.ControlCalibrationTable\x12\x32\n#enable_mpc_feedforward_compensation\x18\x17 \x01(\x08:\x05\x66\x61lse\x12(\n unconstrained_control_diff_limit\x18\x18 \x01(\x01'
  ,
  dependencies=[modules_dot_control_dot_proto_dot_calibration__table__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2.DESCRIPTOR,])




_MPCCONTROLLERCONF = _descriptor.Descriptor(
  name='MPCControllerConf',
  full_name='apollo.control.MPCControllerConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='apollo.control.MPCControllerConf.ts', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cf', full_name='apollo.control.MPCControllerConf.cf', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cr', full_name='apollo.control.MPCControllerConf.cr', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_fl', full_name='apollo.control.MPCControllerConf.mass_fl', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_fr', full_name='apollo.control.MPCControllerConf.mass_fr', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_rl', full_name='apollo.control.MPCControllerConf.mass_rl', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mass_rr', full_name='apollo.control.MPCControllerConf.mass_rr', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eps', full_name='apollo.control.MPCControllerConf.eps', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_q', full_name='apollo.control.MPCControllerConf.matrix_q', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matrix_r', full_name='apollo.control.MPCControllerConf.matrix_r', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cutoff_freq', full_name='apollo.control.MPCControllerConf.cutoff_freq', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean_filter_window_size', full_name='apollo.control.MPCControllerConf.mean_filter_window_size', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_iteration', full_name='apollo.control.MPCControllerConf.max_iteration', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lateral_acceleration', full_name='apollo.control.MPCControllerConf.max_lateral_acceleration', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standstill_acceleration', full_name='apollo.control.MPCControllerConf.standstill_acceleration', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_minimum_action', full_name='apollo.control.MPCControllerConf.brake_minimum_action', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_minimum_action', full_name='apollo.control.MPCControllerConf.throttle_minimum_action', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat_err_gain_scheduler', full_name='apollo.control.MPCControllerConf.lat_err_gain_scheduler', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_err_gain_scheduler', full_name='apollo.control.MPCControllerConf.heading_err_gain_scheduler', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer_weight_gain_scheduler', full_name='apollo.control.MPCControllerConf.steer_weight_gain_scheduler', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedforwardterm_gain_scheduler', full_name='apollo.control.MPCControllerConf.feedforwardterm_gain_scheduler', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_table', full_name='apollo.control.MPCControllerConf.calibration_table', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_mpc_feedforward_compensation', full_name='apollo.control.MPCControllerConf.enable_mpc_feedforward_compensation', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unconstrained_control_diff_limit', full_name='apollo.control.MPCControllerConf.unconstrained_control_diff_limit', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=991,
)

_MPCCONTROLLERCONF.fields_by_name['lat_err_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['heading_err_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['steer_weight_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['feedforwardterm_gain_scheduler'].message_type = modules_dot_control_dot_proto_dot_gain__scheduler__conf__pb2._GAINSCHEDULER
_MPCCONTROLLERCONF.fields_by_name['calibration_table'].message_type = modules_dot_control_dot_proto_dot_calibration__table__pb2._CONTROLCALIBRATIONTABLE
DESCRIPTOR.message_types_by_name['MPCControllerConf'] = _MPCCONTROLLERCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MPCControllerConf = _reflection.GeneratedProtocolMessageType('MPCControllerConf', (_message.Message,), {
  'DESCRIPTOR' : _MPCCONTROLLERCONF,
  '__module__' : 'modules.control.proto.mpc_controller_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MPCControllerConf)
  })
_sym_db.RegisterMessage(MPCControllerConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/vehicle_signal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/vehicle_signal.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/common/proto/vehicle_signal.proto\x12\rapollo.common\"\xd5\x01\n\rVehicleSignal\x12<\n\x0bturn_signal\x18\x01 \x01(\x0e\x32\'.apollo.common.VehicleSignal.TurnSignal\x12\x11\n\thigh_beam\x18\x02 \x01(\x08\x12\x10\n\x08low_beam\x18\x03 \x01(\x08\x12\x0c\n\x04horn\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mergency_light\x18\x05 \x01(\x08\":\n\nTurnSignal\x12\r\n\tTURN_NONE\x10\x00\x12\r\n\tTURN_LEFT\x10\x01\x12\x0e\n\nTURN_RIGHT\x10\x02'
)



_VEHICLESIGNAL_TURNSIGNAL = _descriptor.EnumDescriptor(
  name='TurnSignal',
  full_name='apollo.common.VehicleSignal.TurnSignal',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TURN_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=216,
  serialized_end=274,
)
_sym_db.RegisterEnumDescriptor(_VEHICLESIGNAL_TURNSIGNAL)


_VEHICLESIGNAL = _descriptor.Descriptor(
  name='VehicleSignal',
  full_name='apollo.common.VehicleSignal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='turn_signal', full_name='apollo.common.VehicleSignal.turn_signal', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_beam', full_name='apollo.common.VehicleSignal.high_beam', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_beam', full_name='apollo.common.VehicleSignal.low_beam', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horn', full_name='apollo.common.VehicleSignal.horn', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergency_light', full_name='apollo.common.VehicleSignal.emergency_light', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLESIGNAL_TURNSIGNAL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=274,
)

_VEHICLESIGNAL.fields_by_name['turn_signal'].enum_type = _VEHICLESIGNAL_TURNSIGNAL
_VEHICLESIGNAL_TURNSIGNAL.containing_type = _VEHICLESIGNAL
DESCRIPTOR.message_types_by_name['VehicleSignal'] = _VEHICLESIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VehicleSignal = _reflection.GeneratedProtocolMessageType('VehicleSignal', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESIGNAL,
  '__module__' : 'modules.common.proto.vehicle_signal_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.VehicleSignal)
  })
_sym_db.RegisterMessage(VehicleSignal)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/transport_conf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/transport_conf.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cyber/proto/transport_conf.proto\x12\x12\x61pollo.cyber.proto\"/\n\x13ShmMulticastLocator\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"p\n\x07ShmConf\x12\x15\n\rnotifier_type\x18\x01 \x01(\t\x12\x10\n\x08shm_type\x18\x02 \x01(\t\x12<\n\x0bshm_locator\x18\x03 \x01(\x0b\x32\'.apollo.cyber.proto.ShmMulticastLocator\"\x88\x01\n\x13RtpsParticipantAttr\x12\x1a\n\x0elease_duration\x18\x01 \x01(\x05:\x02\x31\x32\x12\x1e\n\x13\x61nnouncement_period\x18\x02 \x01(\x05:\x01\x33\x12\x1b\n\x0e\x64omain_id_gain\x18\x03 \x01(\r:\x03\x32\x30\x30\x12\x18\n\tport_base\x18\x04 \x01(\r:\x05\x31\x30\x30\x30\x30\"\xc4\x01\n\x11\x43ommunicationMode\x12:\n\tsame_proc\x18\x01 \x01(\x0e\x32 .apollo.cyber.proto.OptionalMode:\x05INTRA\x12\x38\n\tdiff_proc\x18\x02 \x01(\x0e\x32 .apollo.cyber.proto.OptionalMode:\x03SHM\x12\x39\n\tdiff_host\x18\x03 \x01(\x0e\x32 .apollo.cyber.proto.OptionalMode:\x04RTPS\"0\n\rResourceLimit\x12\x1f\n\x11max_history_depth\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\"\xff\x01\n\rTransportConf\x12-\n\x08shm_conf\x18\x01 \x01(\x0b\x32\x1b.apollo.cyber.proto.ShmConf\x12\x41\n\x10participant_attr\x18\x02 \x01(\x0b\x32\'.apollo.cyber.proto.RtpsParticipantAttr\x12\x41\n\x12\x63ommunication_mode\x18\x03 \x01(\x0b\x32%.apollo.cyber.proto.CommunicationMode\x12\x39\n\x0eresource_limit\x18\x04 \x01(\x0b\x32!.apollo.cyber.proto.ResourceLimit*8\n\x0cOptionalMode\x12\n\n\x06HYBRID\x10\x00\x12\t\n\x05INTRA\x10\x01\x12\x07\n\x03SHM\x10\x02\x12\x08\n\x04RTPS\x10\x03'
)

_OPTIONALMODE = _descriptor.EnumDescriptor(
  name='OptionalMode',
  full_name='apollo.cyber.proto.OptionalMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HYBRID', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTRA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTPS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=865,
  serialized_end=921,
)
_sym_db.RegisterEnumDescriptor(_OPTIONALMODE)

OptionalMode = enum_type_wrapper.EnumTypeWrapper(_OPTIONALMODE)
HYBRID = 0
INTRA = 1
SHM = 2
RTPS = 3



_SHMMULTICASTLOCATOR = _descriptor.Descriptor(
  name='ShmMulticastLocator',
  full_name='apollo.cyber.proto.ShmMulticastLocator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='apollo.cyber.proto.ShmMulticastLocator.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='apollo.cyber.proto.ShmMulticastLocator.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=103,
)


_SHMCONF = _descriptor.Descriptor(
  name='ShmConf',
  full_name='apollo.cyber.proto.ShmConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notifier_type', full_name='apollo.cyber.proto.ShmConf.notifier_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shm_type', full_name='apollo.cyber.proto.ShmConf.shm_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shm_locator', full_name='apollo.cyber.proto.ShmConf.shm_locator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=217,
)


_RTPSPARTICIPANTATTR = _descriptor.Descriptor(
  name='RtpsParticipantAttr',
  full_name='apollo.cyber.proto.RtpsParticipantAttr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lease_duration', full_name='apollo.cyber.proto.RtpsParticipantAttr.lease_duration', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=12,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='announcement_period', full_name='apollo.cyber.proto.RtpsParticipantAttr.announcement_period', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain_id_gain', full_name='apollo.cyber.proto.RtpsParticipantAttr.domain_id_gain', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=200,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_base', full_name='apollo.cyber.proto.RtpsParticipantAttr.port_base', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=10000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=356,
)


_COMMUNICATIONMODE = _descriptor.Descriptor(
  name='CommunicationMode',
  full_name='apollo.cyber.proto.CommunicationMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='same_proc', full_name='apollo.cyber.proto.CommunicationMode.same_proc', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diff_proc', full_name='apollo.cyber.proto.CommunicationMode.diff_proc', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diff_host', full_name='apollo.cyber.proto.CommunicationMode.diff_host', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=555,
)


_RESOURCELIMIT = _descriptor.Descriptor(
  name='ResourceLimit',
  full_name='apollo.cyber.proto.ResourceLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_history_depth', full_name='apollo.cyber.proto.ResourceLimit.max_history_depth', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=557,
  serialized_end=605,
)


_TRANSPORTCONF = _descriptor.Descriptor(
  name='TransportConf',
  full_name='apollo.cyber.proto.TransportConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shm_conf', full_name='apollo.cyber.proto.TransportConf.shm_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_attr', full_name='apollo.cyber.proto.TransportConf.participant_attr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='communication_mode', full_name='apollo.cyber.proto.TransportConf.communication_mode', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_limit', full_name='apollo.cyber.proto.TransportConf.resource_limit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=863,
)

_SHMCONF.fields_by_name['shm_locator'].message_type = _SHMMULTICASTLOCATOR
_COMMUNICATIONMODE.fields_by_name['same_proc'].enum_type = _OPTIONALMODE
_COMMUNICATIONMODE.fields_by_name['diff_proc'].enum_type = _OPTIONALMODE
_COMMUNICATIONMODE.fields_by_name['diff_host'].enum_type = _OPTIONALMODE
_TRANSPORTCONF.fields_by_name['shm_conf'].message_type = _SHMCONF
_TRANSPORTCONF.fields_by_name['participant_attr'].message_type = _RTPSPARTICIPANTATTR
_TRANSPORTCONF.fields_by_name['communication_mode'].message_type = _COMMUNICATIONMODE
_TRANSPORTCONF.fields_by_name['resource_limit'].message_type = _RESOURCELIMIT
DESCRIPTOR.message_types_by_name['ShmMulticastLocator'] = _SHMMULTICASTLOCATOR
DESCRIPTOR.message_types_by_name['ShmConf'] = _SHMCONF
DESCRIPTOR.message_types_by_name['RtpsParticipantAttr'] = _RTPSPARTICIPANTATTR
DESCRIPTOR.message_types_by_name['CommunicationMode'] = _COMMUNICATIONMODE
DESCRIPTOR.message_types_by_name['ResourceLimit'] = _RESOURCELIMIT
DESCRIPTOR.message_types_by_name['TransportConf'] = _TRANSPORTCONF
DESCRIPTOR.enum_types_by_name['OptionalMode'] = _OPTIONALMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ShmMulticastLocator = _reflection.GeneratedProtocolMessageType('ShmMulticastLocator', (_message.Message,), {
  'DESCRIPTOR' : _SHMMULTICASTLOCATOR,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ShmMulticastLocator)
  })
_sym_db.RegisterMessage(ShmMulticastLocator)

ShmConf = _reflection.GeneratedProtocolMessageType('ShmConf', (_message.Message,), {
  'DESCRIPTOR' : _SHMCONF,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ShmConf)
  })
_sym_db.RegisterMessage(ShmConf)

RtpsParticipantAttr = _reflection.GeneratedProtocolMessageType('RtpsParticipantAttr', (_message.Message,), {
  'DESCRIPTOR' : _RTPSPARTICIPANTATTR,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.RtpsParticipantAttr)
  })
_sym_db.RegisterMessage(RtpsParticipantAttr)

CommunicationMode = _reflection.GeneratedProtocolMessageType('CommunicationMode', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNICATIONMODE,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.CommunicationMode)
  })
_sym_db.RegisterMessage(CommunicationMode)

ResourceLimit = _reflection.GeneratedProtocolMessageType('ResourceLimit', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELIMIT,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ResourceLimit)
  })
_sym_db.RegisterMessage(ResourceLimit)

TransportConf = _reflection.GeneratedProtocolMessageType('TransportConf', (_message.Message,), {
  'DESCRIPTOR' : _TRANSPORTCONF,
  '__module__' : 'cyber.proto.transport_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.TransportConf)
  })
_sym_db.RegisterMessage(TransportConf)


# @@protoc_insertion_point(module_scope)
